@@ -115,7 +115,11 @@ setMethod(
     RxC <- x.dim[1L] != 1L # check if `x` is a column-vector (and thus y is a row-vector)
     out <- .rcpp_bc_str_ov(x, y, RxC, out.dimsimp, out.len, op)
   }
-  else if(dimmode == 3L) { # general mode
+  else if(dimmode == 3L) {
+    bigx <- .C_dims_allge(x.dim, y.dim)
+    out <- .rcpp_bc_str_bv(x, y, bigx, out.dimsimp, out.len, op)
+  }
+  else if(dimmode == 4L) { # general mode
     
     by_x <- .C_make_by(x.dim)
     by_y <- .C_make_by(y.dim)
@@ -128,7 +132,7 @@ setMethod(
     )
   }
   
-  dim(out) <- out.dimorig
+  .rcpp_set_attr(out, "dim", out.dimorig)
   
   .binary_set_attr(out, x, y)
   
@@ -161,7 +165,11 @@ setMethod(
     RxC <- x.dim[1L] != 1L # check if `x` is a column-vector (and thus y is a row-vector)
     out <- .rcpp_bcRel_str_ov(x, y, RxC, out.dimsimp, out.len, op)
   }
-  else if(dimmode == 3L) { # general mode
+  else if(dimmode == 3L) {
+    bigx <- .C_dims_allge(x.dim, y.dim)
+    out <- .rcpp_bcRel_str_bv(x, y, bigx, out.dimsimp, out.len, op)
+  }
+  else if(dimmode == 4L) { # general mode
     
     by_x <- .C_make_by(x.dim)
     by_y <- .C_make_by(y.dim)
@@ -174,7 +182,7 @@ setMethod(
     )
   }
   
-  dim(out) <- out.dimorig
+  .rcpp_set_attr(out, "dim", out.dimorig)
   
   .binary_set_attr(out, x, y)
   
@@ -201,26 +209,30 @@ setMethod(
   dimmode <- prep[[6L]]
   
   if(dimmode == 1L) { # vector mode
-    out <- .rcpp_bcDist_str_v(x, y, out.len, op)
+    out <- .rcpp_bcD_str_v(x, y, out.len, op)
   }
   else if(dimmode == 2L) { # orthogonal vector mode
     RxC <- x.dim[1L] != 1L # check if `x` is a column-vector (and thus y is a row-vector)
-    out <- .rcpp_bcDist_str_ov(x, y, RxC, out.dimsimp, out.len, op)
+    out <- .rcpp_bcD_str_ov(x, y, RxC, out.dimsimp, out.len, op)
   }
-  else if(dimmode == 3L) { # general mode
+  else if(dimmode == 3L) {
+    bigx <- .C_dims_allge(x.dim, y.dim)
+    out <- .rcpp_bcD_str_bv(x, y, bigx, out.dimsimp, out.len, op)
+  }
+  else if(dimmode == 4L) { # general mode
     
     by_x <- .C_make_by(x.dim)
     by_y <- .C_make_by(y.dim)
     dcp_x <- .C_make_dcp(x.dim)
     dcp_y <- .C_make_dcp(y.dim)
     
-    out <- .rcpp_bcDist_str_d(
+    out <- .rcpp_bcD_str_d(
       x, y, by_x, by_y,
       dcp_x, dcp_y, as.integer(out.dimsimp), out.len, op
     )
   }
   
-  dim(out) <- out.dimorig
+  .rcpp_set_attr(out, "dim", out.dimorig)
   
   .binary_set_attr(out, x, y)
   
