@@ -5,8 +5,7 @@
   if(!is.list(input)) {
     stop(simpleError("`input` must be a list", call = abortcall))
   }
-  all_arrays <- vapply(input, is.array, logical(1L)) |> all()
-  if(!all_arrays) {
+  if(.C_any_nonarray(input)) {
     stop(simpleError("can only bind arrays", call = abortcall))
   }
   if(length(input) < 2L) {
@@ -80,15 +79,21 @@
 
 #' @keywords internal
 #' @noRd
-.bind_normalize_dims <- function(input.dims, dimlens, along, max_ndims) {
+.bind_make_input_dims <- function(input.dims, along, max_ndims) {
+  
+  # this function does 2 things:
+  # - adjust the dimensions of the input according to the `along` argument (like when along = 0)
+  # - normalize the input dimensions, required for further computing
+  # this function does not chunkify the dimensions, as that is done virtually within 'C++'
+  
   if(along > 0L && along <= max_ndims) {
-    return(.rcpp_normalize_dims(input.dims, 0L, max_ndims))
+    return(.rcpp_bindhelper_make_input_dims(input.dims, 0L, max_ndims))
   }
   else if(along == 0L) {
-    return(.rcpp_normalize_dims(input.dims, 1L, max_ndims + 1L))
+    return(.rcpp_bindhelper_make_input_dims(input.dims, 1L, max_ndims + 1L))
   }
   else if(along == (max_ndims + 1L)) {
-    return(.rcpp_normalize_dims(input.dims, 0L, max_ndims + 1L))
+    return(.rcpp_bindhelper_make_input_dims(input.dims, 0L, max_ndims + 1L))
   }
 }
 
@@ -98,9 +103,6 @@
 #' @noRd
 .internal_bind_array <- function(input, along, ndim2bc, name_along, abortcall) {
   
-  INTMAX <- 2^31 - 1L
-  LONGMAX <- 2^52 - 1L
-  
   # check ndim2bc:
   if(!.is.integer_scalar(ndim2bc)) {
     stop(simpleError("`ndim2bc` must be an integer scalar", call = abortcall))
@@ -115,13 +117,8 @@
   # NOTE: all empty input already covered before running this function
   input <- input[lengths(input) > 0L] 
   
-  # make input.dims:
-  input.dims <- .C_bindhelper_vdims(input)
-  dimlens <- lengths(input.dims)
-  
-  
-  # check max ndims:
-  max_ndims <- max(dimlens)
+  # determine max_ndims:
+  max_ndims <- max(lst.ndim(input))
   .bind_check_max_ndims(max_ndims, along, abortcall)
   
   
@@ -133,26 +130,21 @@
   
   
   # normalize input.dims:
-  input.dims <- .bind_normalize_dims(input.dims, dimlens, along, max_ndims)
-  dimlens <- lengths(input.dims)
+  input.dims <- .bind_make_input_dims(input, along, max_ndims)
   if(along == 0L) along <- 1L
-  max_ndims <- max(dimlens)
+  max_ndims <- length(input.dims[[1L]])
   
   
   # get naming params - must do this AFTER normalizing dims!
   if(name_along && !extra_dimensional) {
     # note: dimension `along` never gets broadcasted, so no need to worry about that
     arg.dimnames <- .rcpp_bindhelper_get_dimnames(input, along)
-    arg.marginlen <- vapply(input.dims, \(x)(x)[along], integer(1L))
+    arg.marginlen <- .C_bindhelper_get_alongdims(input.dims, along - 1L)
     name_along <- .bind_name_along_reasonable(input, arg.dimnames)
   }
   
   
   # check dimlens:
-  if(length(unique(dimlens)) > 1L) {
-    stop("input malformed")
-  }
-  max_ndims <- max(dimlens)
   if(max_ndims > 16L) {
     stop(simpleError(
       "arrays with more than 16 dimensions are not supported", call = abortcall
@@ -160,28 +152,11 @@
   }
   
   # determine original out.dim:
-  out.dimorig <- do.call(pmax, input.dims)
-  
-  # chunkify input.dims:
-  input.dims <- lapply(input.dims, .C_chunkify_dims, chunks = c(2L, 4L, 8L, 16L))
-  dimlens <- lengths(input.dims)
-  max_ndims <- max(dimlens)
-  
-  # determine out.dim (padded):
-  size_along <- .C_bindhelper_sum_along(input.dims, along - 1L)
-  out.dim <- do.call(pmax, input.dims)
-  out.dim[along] <- size_along
-  out.dimorig[along] <- size_along # original dimensions
-  out.dim
-  out.dim <- as.integer(out.dim)
-  out.len <- prod(out.dim)
-  if(any(out.dim > INTMAX) || anyNA(out.dim) || out.len > LONGMAX) {
-    stop(simpleError("output will exceed maximum vector size", call = abortcall))
-  }
+  out.dimorig <- as.integer(do.call(pmax, input.dims))
   
   
   # check if input is conformable:
-  conf <- .rcpp_bindhelper_conf_dims_all(input.dims, out.dim, along - 1L, ndim2bc)
+  conf <- .rcpp_bindhelper_conf_dims_all(input.dims, out.dimorig, along - 1L, ndim2bc)
   if(conf < 0) {
     stop(simpleError("arrays are not conformable for binding", call = abortcall))
   }
@@ -193,6 +168,24 @@
     stop(simpleError(txt, call = abortcall))
   }
   
+  
+  # set chunksize:
+  chunksize <- 16L # using static chunksize, as that's easier to test with unitests
+  
+  
+  # determine out.dim (padded):
+  size_along <- .C_bindhelper_sum_along(input.dims, along - 1L)
+  out.dim <- rep(1L, chunksize)
+  out.dim[1:max_ndims] <- do.call(pmax, input.dims)
+  out.dim[along] <- size_along
+  out.dimorig[along] <- size_along # original dimensions
+  out.dim <- as.integer(out.dim)
+  out.len <- prod(out.dim)
+  if(.C_arraysize_overflow(out.dim, out.len)) {
+    stop(simpleError("output will exceed maximum vector size", call = abortcall))
+  }
+  
+  
   # determine "highest" type:
   out.type <- .C_bindhelper_max_type(input)
   out.type <- .types()[out.type]
@@ -200,62 +193,70 @@
     stop(simpleError("unknown type of array given", call = abortcall))
   }
   
+  
   # allocate output:
   out <- vector(out.type, out.len)
-  dim(out) <- out.dimorig
+  .rcpp_set_attr(out, "dim", out.dimorig)
   
   
-  # alias coercion function:
+  # determine which needs coercion:
   mycoerce <- .type_alias_coerce(out.type, abortcall)
+  need_coerce <- .C_bindhelper_need_coerce(input, out)
   
   
   # MAIN FUNCTION:
-  counter <- 1L
-  max_ndims <- length(out.dim)
+  counter <- 0L
   dcp_out <- .C_make_dcp(out.dim)
+  starts <- .rcpp_clone(rep(0L, chunksize))
+  ends <- .rcpp_clone(out.dim)
+  by_x <- vector("integer", chunksize)
+  dcp_x <- vector("double", chunksize+1)
+  size_along <- 0L
+  
   for(i in 1:length(input)) {
     
     # construct parameters:
     x <- input[[i]]
     x.dim <- input.dims[[i]]
     size_along <- x.dim[along]
-    starts <- rep(1L, max_ndims)
-    starts[along] <- counter
-    ends <- out.dim
-    ends[along] <- counter + size_along - 1L
-    by_x <- .C_make_by(x.dim)
-    by_x[along] <- 1L
-    dcp_x <- .C_make_dcp(x.dim)
+    
     
     # coerce input if necessary:
-    if(typeof(x) != typeof(out)) {
+    if(need_coerce[i]) {
       x <- mycoerce(x)
     }
     
+    
     # pass-by-reference modification:
-    .rcpp_bc_bind(out, x, starts - 1L, ends -1L, by_x, dcp_out, dcp_x, out.dim)
+    .rcpp_bc_bind_prep(
+      starts, ends, by_x, dcp_x, x.dim, out.dim, along - 1L, size_along, counter, chunksize
+    )
+    
+    .rcpp_bc_bind(out, x, starts, ends, by_x, dcp_out, dcp_x, out.dim)
+    
     
     # set counter:
     counter <- counter + size_along
+    
   }
   
   
-  
   # name_along:
   if(name_along) {
     
-    dimnames(out) <- .bind_prep_dimnames(out)
+    out.dimnames <- .bind_prep_dimnames(out)
     
     if(!extra_dimensional) {
-      dimnames(out)[[along]] <- .bind_get_alongnames(out, along, input, arg.dimnames, arg.marginlen)
+      out.dimnames[[along]] <- .bind_get_alongnames(dim(out), along, input, arg.dimnames, arg.marginlen)
     }
     else if(extra_dimensional) {
       if(!is.null(names(input))) {
-        dimnames(out)[[along]] <- names(input)
+        out.dimnames[[along]] <- names(input)
       } else {
-        dimnames(out)[[along]] <- paste0("X", seq_len(dim(out)[along]))
+        out.dimnames[[along]] <- paste0("X", seq_len(dim(out)[along]))
       }
     }
+    .set_dimnames(out, out.dimnames)
   }
   
   return(out)
