@@ -106,7 +106,7 @@
   
   
   if(is.complex(e1) || is.complex(e2)) {
-    stop("`^` operator not (yet) supported for type `complex`")
+    stop("operator not defined for complex numbers")
   }
   else if(.is_numeric_like(e1) && .is_numeric_like(e2)) {
     out <- .bc_dec_math(e1, e2, 5L, sys.call())
@@ -129,7 +129,7 @@
     stop("`%%` operator not supported for type `complex`")
   }
   else if(.is_numeric_like(e1) && .is_numeric_like(e2)) {
-    out <- .bc_int_fact(e1, e2, 2L, sys.call())
+    out <- .bc_int_d(e1, e2, 2L, sys.call())
   }
   else {
     stop("non-numeric argument to binary operator")
@@ -148,7 +148,7 @@
     stop("`%/%` operator not supported for type `complex`")
   }
   else if(.is_numeric_like(e1) && .is_numeric_like(e2)) {
-    out <- .bc_int_fact(e1, e2, 3L, sys.call())
+    out <- .bc_int_d(e1, e2, 3L, sys.call())
   }
   else {
     stop("non-numeric argument to binary operator")
