@@ -10,7 +10,7 @@ using namespace Rcpp;
 
 //' @keywords internal
 //' @noRd
-// [[Rcpp::export(.rcpp_bcRel_dec_v)]]
+// [[Rcpp::export(.rcpp_bcRel_dec_v, rng = false)]]
 SEXP rcpp_bcRel_dec_v(
   SEXP x, SEXP y,
   R_xlen_t nout, int op
@@ -35,7 +35,7 @@ return out;
 
 //' @keywords internal
 //' @noRd
-// [[Rcpp::export(.rcpp_bcRel_dec_ov)]]
+// [[Rcpp::export(.rcpp_bcRel_dec_ov, rng = false)]]
 SEXP rcpp_bcRel_dec_ov(
   SEXP x, SEXP y, bool RxC, SEXP out_dim,
   R_xlen_t nout, int op
@@ -59,7 +59,31 @@ return out;
 
 //' @keywords internal
 //' @noRd
-// [[Rcpp::export(.rcpp_bcRel_dec_d)]]
+// [[Rcpp::export(.rcpp_bcRel_dec_bv, rng = false)]]
+SEXP rcpp_bcRel_dec_bv(
+  SEXP x, SEXP y, bool bigx, SEXP out_dim,
+  R_xlen_t nout, int op
+) {
+
+int tempout;
+
+SEXP out = PROTECT(Rf_allocVector(LGLSXP, nout));
+int *pout;
+pout = LOGICAL(out);
+
+MACRO_OP_DEC_REL(MACRO_DIM_BIG2VECTOR);
+
+UNPROTECT(1);
+return out;
+
+}
+
+
+
+
+//' @keywords internal
+//' @noRd
+// [[Rcpp::export(.rcpp_bcRel_dec_d, rng = false)]]
 SEXP rcpp_bcRel_dec_d(
   SEXP x, SEXP y,
   SEXP by_x,
