@@ -10,7 +10,7 @@ using namespace Rcpp;
 
 //' @keywords internal
 //' @noRd
-// [[Rcpp::export(.rcpp_bcRel_int_v)]]
+// [[Rcpp::export(.rcpp_bcRel_int_v, rng = false)]]
 SEXP rcpp_bcRel_int_v(
   SEXP x, SEXP y,
   R_xlen_t nout, int op
@@ -36,7 +36,7 @@ return out;
 
 //' @keywords internal
 //' @noRd
-// [[Rcpp::export(.rcpp_bcRel_int_ov)]]
+// [[Rcpp::export(.rcpp_bcRel_int_ov, rng = false)]]
 SEXP rcpp_bcRel_int_ov(
   SEXP x, SEXP y, bool RxC, SEXP out_dim,
   R_xlen_t nout, int op
@@ -61,7 +61,32 @@ return out;
 
 //' @keywords internal
 //' @noRd
-// [[Rcpp::export(.rcpp_bcRel_int_d)]]
+// [[Rcpp::export(.rcpp_bcRel_int_bv, rng = false)]]
+SEXP rcpp_bcRel_int_bv(
+  SEXP x, SEXP y, bool bigx, SEXP out_dim,
+  R_xlen_t nout, int op
+) {
+
+
+int tempout;
+
+SEXP out = PROTECT(Rf_allocVector(LGLSXP, nout));
+int *pout;
+pout = LOGICAL(out);
+
+MACRO_OP_INT_REL(MACRO_DIM_BIG2VECTOR);
+
+UNPROTECT(1);
+return out;
+
+}
+
+
+
+
+//' @keywords internal
+//' @noRd
+// [[Rcpp::export(.rcpp_bcRel_int_d, rng = false)]]
 SEXP rcpp_bcRel_int_d(
   SEXP x, SEXP y,
   SEXP by_x,
