@@ -10,7 +10,7 @@ using namespace Rcpp;
 
 //' @keywords internal
 //' @noRd
-// [[Rcpp::export(.rcpp_bcRel_raw_v)]]
+// [[Rcpp::export(.rcpp_bcRel_raw_v, rng = false)]]
 SEXP rcpp_bcRel_raw_v(
   SEXP x, SEXP y,
   R_xlen_t nout, int op
@@ -34,7 +34,7 @@ return out;
 
 //' @keywords internal
 //' @noRd
-// [[Rcpp::export(.rcpp_bcRel_raw_ov)]]
+// [[Rcpp::export(.rcpp_bcRel_raw_ov, rng = false)]]
 SEXP rcpp_bcRel_raw_ov(
   SEXP x, SEXP y, bool RxC, SEXP out_dim,
   R_xlen_t nout, int op
@@ -58,7 +58,31 @@ return out;
 
 //' @keywords internal
 //' @noRd
-// [[Rcpp::export(.rcpp_bcRel_raw_d)]]
+// [[Rcpp::export(.rcpp_bcRel_raw_bv, rng = false)]]
+SEXP rcpp_bcRel_raw_bv(
+  SEXP x, SEXP y, bool bigx, SEXP out_dim,
+  R_xlen_t nout, int op
+) {
+
+
+SEXP out = PROTECT(Rf_allocVector(LGLSXP, nout));
+int *pout = LOGICAL(out);
+Rbyte *px = RAW(x);
+Rbyte *py = RAW(y);
+
+MACRO_OP_RAW_REL(MACRO_DIM_BIG2VECTOR);
+
+UNPROTECT(1);
+return out;
+
+}
+
+
+
+
+//' @keywords internal
+//' @noRd
+// [[Rcpp::export(.rcpp_bcRel_raw_d, rng = false)]]
 SEXP rcpp_bcRel_raw_d(
   SEXP x, SEXP y,
   SEXP by_x,
