@@ -18,7 +18,7 @@ inline Rbyte rcpp_raw_diff(Rbyte x, Rbyte y) {
 
 //' @keywords internal
 //' @noRd
-// [[Rcpp::export(.rcpp_bc_raw_v)]]
+// [[Rcpp::export(.rcpp_bc_raw_v, rng = false)]]
 SEXP rcpp_bc_raw_v(
   SEXP x, SEXP y,
   R_xlen_t nout, int op
@@ -42,7 +42,7 @@ return out;
 
 //' @keywords internal
 //' @noRd
-// [[Rcpp::export(.rcpp_bc_raw_ov)]]
+// [[Rcpp::export(.rcpp_bc_raw_ov, rng = false)]]
 SEXP rcpp_bc_raw_ov(
   SEXP x, SEXP y, bool RxC, SEXP out_dim,
   R_xlen_t nout, int op
@@ -66,7 +66,31 @@ return out;
 
 //' @keywords internal
 //' @noRd
-// [[Rcpp::export(.rcpp_bc_raw_d)]]
+// [[Rcpp::export(.rcpp_bc_raw_bv, rng = false)]]
+SEXP rcpp_bc_raw_bv(
+  SEXP x, SEXP y, bool bigx, SEXP out_dim,
+  R_xlen_t nout, int op
+) {
+
+
+SEXP out = PROTECT(Rf_allocVector(RAWSXP, nout));
+Rbyte *pout = RAW(out);
+Rbyte *px = RAW(x);
+Rbyte *py = RAW(y);
+
+MACRO_OP_RAW_BYTE(MACRO_DIM_BIG2VECTOR);
+
+UNPROTECT(1);
+return out;
+
+}
+
+
+
+
+//' @keywords internal
+//' @noRd
+// [[Rcpp::export(.rcpp_bc_raw_d, rng = false)]]
 SEXP rcpp_bc_raw_d(
   SEXP x, SEXP y,
   SEXP by_x,
