@@ -7,6 +7,7 @@ using namespace Rcpp;
 
 
 
+
 inline String rcpp_string_plus(
     String x, String y
   ) {
@@ -24,7 +25,7 @@ inline String rcpp_string_plus(
 
 //' @keywords internal
 //' @noRd
-// [[Rcpp::export(.rcpp_bc_str_v)]]
+// [[Rcpp::export(.rcpp_bc_str_v, rng = false)]]
 SEXP rcpp_bc_str_v(
   SEXP x, SEXP y, 
   R_xlen_t nout, int op
@@ -48,7 +49,7 @@ return out;
 
 //' @keywords internal
 //' @noRd
-// [[Rcpp::export(.rcpp_bc_str_ov)]]
+// [[Rcpp::export(.rcpp_bc_str_ov, rng = false)]]
 SEXP rcpp_bc_str_ov(
   SEXP x, SEXP y,  bool RxC, SEXP out_dim,
   R_xlen_t nout, int op
@@ -73,7 +74,32 @@ return out;
 
 //' @keywords internal
 //' @noRd
-// [[Rcpp::export(.rcpp_bc_str_d)]]
+// [[Rcpp::export(.rcpp_bc_str_bv, rng = false)]]
+SEXP rcpp_bc_str_bv(
+  SEXP x, SEXP y,  bool bigx, SEXP out_dim,
+  R_xlen_t nout, int op
+) {
+
+const SEXP *px = STRING_PTR_RO(x);
+const SEXP *py = STRING_PTR_RO(y);
+
+CharacterVector out(nout);
+
+MACRO_OP_STR_PLUS(
+  MACRO_DIM_BIG2VECTOR
+);
+
+
+return out;
+
+}
+
+
+
+
+//' @keywords internal
+//' @noRd
+// [[Rcpp::export(.rcpp_bc_str_d, rng = false)]]
 SEXP rcpp_bc_str_d(
   SEXP x, SEXP y, 
   SEXP by_x,
